@@ -76,8 +76,39 @@ $(function() {
 		indentWithTabs: true,
 		readOnly: true
 	});
+
+	outputEditor.setValue("Output from running processes is shown here.\nPlease run a script to show something useful");
+
+	var diffEditor = CodeMirror.fromTextArea(document.getElementById('diff'), {
+		//TODO these should be configurable!
+		tabSize: 4,
+		indentUnit: 4,
+		indentWithTabs: true,
+		readOnly: true
+	});
+
+	// Some friendly advice
+	diffEditor.setValue("This will contain commit changes.\nPlease use Git Diff to show something useful");
 	
-	
+	$('a[href="#input-tab"]').click(function() { 
+		setTimeout(function() {
+			inputEditor.refresh();
+		}, 0);
+		
+	});
+
+	$('a[href="#output-tab"]').click(function() { 
+		setTimeout(function() {
+			outputEditor.refresh();
+		}, 0);
+	});
+
+	$('a[href="#diff-tab"]').click(function() { 
+		setTimeout(function() {
+			diffEditor.refresh();
+		}, 0);
+	});
+
 	var messages = [];
 
 	window.sendMessage = function(action, params, callback) {
@@ -125,6 +156,9 @@ $(function() {
 					// Add an empty one editor tab on startup
 					AddEditorTab();
 					firstTime = false;
+					
+					// Set diff editor mode
+					window.ChangeMode(diffEditor, 'diff');
 				}
 			};
 
@@ -838,5 +872,52 @@ $(function() {
 	$(".navbar .brand").click(function() {
 		$(document).trigger("action-about");
 	});
+	
+	$(document).on('action-debug-step-in', function() {
+		alert("Not implemented yet");
+	});
+
+	$(document).on('action-debug-step-over', function() {
+		alert("Not implemented yet");
+	});
+	
+	$(document).on('action-debug-step-out', function() {
+		alert("Not implemented yet");
+	});
+
+	$(document).on('action-debug-stop', function() {
+		alert("Not implemented yet");
+	});
+
+	$(document).on('action-git-diff', function() {
+		window.sendMessage('git-diff', {}, function(result) {
+
+			diffEditor.setValue('');
+
+			// Handle STDERR
+			if (result.stderr.length) {
+				diffEditor.setValue(result.stderr + "\n");
+			}
+
+			// Handle STDOUT
+			diffEditor.setValue(diffEditor.getValue() + result.stdout);
+
+			// Show diff tab
+			$('a[href="#diff-tab"]').tab('show');
+
+			diffEditor.refresh();
+		});
+	});
+
+	$(document).on('action-perl-strip', function() {
+		var editor = GetCurrentEditor();
+		window.sendMessage('perl-strip', {source: editor.getValue()}, function(result) {
+			if(result.error) {
+				editor.setValue(result.source);
+			} else {
+				alert("No result");
+			}
+		});
+	});
 
 });
